# VoiLib

VoiLib is a Python library for creating virtual assistants using OpenAI and document retrieval.

## Features
- Support for OpenAI's GPT models
- Retrieval-Augmented Generation (RAG)
- Custom intents and automatic replies
